class Breweries(object):
    resource_url = 'breweries'


class Brewery(object):

    """

    """

    resource_url = 'brewery'

    def __init__(self, data):
        self.data = data

    def __unicode__(self):
        return self.name

    @property
    def id(self):
        return self.data['id']

    @property
    def description(self):
        return self.data['description']

    @property
    def name(self):
        return self.data['name']

    @property
    def established(self):
        return self.data['established']

    @property
    def organic(self):
        if self.data['isOrganic'] == 'Y':
            return True
        return False

    @property
    def website(self):
        return self.data['website']

    @property
    def large_image(self):
        return self.data['images']['large']

    @property
    def medium_image(self):
        return self.data['images']['medium']




# -*- coding: utf-8 -*-

__author__ = 'Derek Stegelman'

import json
import requests
import urllib

from .beer import Beer, Beers
from .brewery import Brewery, Breweries

BASE_URL = 'http://api.brewerydb.com/v2'


class BreweryDB(object):
    def __init__(self, api_key):
        self.api_key = api_key
        
    def _auth(self):
        return "key=%s" % self.api_key
        
    def _call(self, resource_url, params=None):
        url = "%s/%s" % (BASE_URL, resource_url)
        
        if params:
            url += "?%s&%s" % (params, self._auth())
        else:
            url += "?%s" % self._auth()
        
        return requests.get(url)
    
    def _params(self, params):
        """
        Takes dictionary of parameters and returns
        urlencoded string

        :param params: Dict of query params to encode
        :type params: dict
        
        :returns:  str -- URL encoded query parameters
        """
        return urllib.urlencode(params)
    
    def search_beer(self, beer_name):
        response = json.loads(self._call(Beers.resource_url, self._params(params={'name': beer_name, 'wwithBreweries': 'Y'})).text)
        beers = []
        for beer in response['data']:
            beers.append(Beers(beer))
        return beers
        
    def get_beer(self, id):
        response = json.loads(self._call("%s/%s" % (Beer.resource_url, id), self._params({'withBreweries': 'Y'})).text)
        return Beer(response['data'])

    def search_breweries(self, brewery_name):
        response = json.loads(self._call(Breweries.resource_url, self._params(params={'name': brewery_name})).text)
        print(response)
        breweries = []
        for brewery in response['data']:
            breweries.append(Brewery(brewery))
        return breweries
    
    def get_brewery(self, id):
        response = json.loads(self._call("%s/%s" % (Brewery.resource_url, id)).text)
        return Brewery(response['data'])


class Beer(object):
    resource_url = 'beer'
    
    def __init__(self, data):
        self.data = data

    def __unicode__(self):
        return self.name
        
    @property
    def name(self):
        return self.data['name']
    
    @property
    def id(self):
        return self.data['id']
    
    @property
    def abv(self):
        return self.data['abv']
    
    @property
    def ibu(self):
        return self.data['ibu']
    
    @property
    def description(self):
        return self.data['description']
    
    @property
    def organic(self):
        if self.data['isOrganic'] == 'Y':
            return True
        return False
    
    @property
    def label_images(self):
        return {'large': self.data['labels']['large'],
                'medium': self.data['labels']['medium']}
    
    @property
    def brewery_id(self):
        return self.data['breweries'][0]['id']
    
    
    
class Beers(Beer):
    resource_url = 'beers'


from setuptools import setup, find_packages

version = '0.1.1'

setup(name='pybrewerydb',
      version=version,
      description="Python wrapper for the BreweryDB API",
      long_description=open("README.md", "r").read(),
      classifiers=[
          "Development Status :: 1 - Planning",
          "Environment :: Console",
          "Intended Audience :: Developers",
          "Natural Language :: English",
          "Operating System :: OS Independent",
          "Programming Language :: Python",
          "Topic :: Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries",
          "Topic :: Utilities",
          "License :: OSI Approved :: MIT License",
          ],
      keywords='beer brewerydb api python',
      author='Derek Stegelman',
      author_email='dstegelman@gmail.com',
      url='http://github.com/dstegelman/PyBreweryDB',
      license='MIT',
      packages=find_packages(),
      install_requires=['requests'],
      include_package_data=True,
      zip_safe=True,
      )